==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/StructuredDataTypeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataType;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.StructureMemberSetImpl;

import java.util.Arrays;
import java.util.List;


public class StructuredDataTypeSetImpl extends InstanceSet<StructuredDataTypeSet,StructuredDataType> implements StructuredDataTypeSet {

    // attributes
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( StructuredDataType structureddatatype : this ) structureddatatype.setDT_ID( ref_DT_ID );
    }


    // selections
    @Override
    public DataTypeSet R17_is_a_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( StructuredDataType structureddatatype : this ) datatypeset.add( structureddatatype.R17_is_a_DataType() );
        return datatypeset;
    }
    @Override
    public StructureMemberSet R44_has_member_StructureMember() throws XtumlException {
        StructureMemberSet structurememberset = new StructureMemberSetImpl();
        for ( StructuredDataType structureddatatype : this ) structurememberset.addAll( structureddatatype.R44_has_member_StructureMember() );
        return structurememberset;
    }


    @Override
    public StructuredDataType nullElement() {
        return StructuredDataTypeImpl.EMPTY_STRUCTUREDDATATYPE;
    }

    @Override
    public StructuredDataTypeSet emptySet() {
      return new StructuredDataTypeSetImpl();
    }

    @Override
    public StructuredDataTypeSet value() {
        return this;
    }

    @Override
    public List<StructuredDataType> elements() {
        return Arrays.asList(toArray(new StructuredDataType[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/StructuredDataTypeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataType;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.StructureMemberSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class StructuredDataTypeSetImpl extends InstanceSet<StructuredDataTypeSet,StructuredDataType> implements StructuredDataTypeSet {

    public StructuredDataTypeSetImpl() {
    }

    public StructuredDataTypeSetImpl(Comparator<? super StructuredDataType> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( StructuredDataType structureddatatype : this ) structureddatatype.setDT_ID( ref_DT_ID );
    }


    // selections
    @Override
    public DataTypeSet R17_is_a_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( StructuredDataType structureddatatype : this ) datatypeset.add( structureddatatype.R17_is_a_DataType() );
        return datatypeset;
    }
    @Override
    public StructureMemberSet R44_has_member_StructureMember() throws XtumlException {
        StructureMemberSet structurememberset = new StructureMemberSetImpl();
        for ( StructuredDataType structureddatatype : this ) structurememberset.addAll( structureddatatype.R44_has_member_StructureMember() );
        return structurememberset;
    }


    @Override
    public StructuredDataType nullElement() {
        return StructuredDataTypeImpl.EMPTY_STRUCTUREDDATATYPE;
    }

    @Override
    public StructuredDataTypeSet emptySet() {
      return new StructuredDataTypeSetImpl();
    }

    @Override
    public StructuredDataTypeSet emptySet(Comparator<? super StructuredDataType> comp) {
      return new StructuredDataTypeSetImpl(comp);
    }

    @Override
    public StructuredDataTypeSet value() {
        return this;
    }

    @Override
    public List<StructuredDataType> elements() {
        return Arrays.asList(toArray(new StructuredDataType[0]));
    }

}
